@@ -29,28 +29,30 @@ use warnings;
 use autodie;
 
 use List::MoreUtils qw(uniq);
-use Moo;
 
-use Lintian::Tags qw(tag);
 use Lintian::Util qw(safe_qx);
 
-with('Lintian::Check');
-
 use constant EMPTY => q{};
 use constant SPACE => q{ };
 
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
+
 sub source {
     my ($self) = @_;
 
     my $pkg = $self->package;
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    for my $bin ($info->binaries) {
+    for my $bin ($processable->binaries) {
 
         next
-          unless $info->binary_field($bin, 'multi-arch', EMPTY) eq 'same';
+          unless $processable->binary_field($bin, 'multi-arch', EMPTY) eq
+          'same';
 
-        my $wildcard = $info->binary_field($bin, 'architecture');
+        my $wildcard = $processable->binary_field($bin, 'architecture');
         my @arches   = split(
             SPACE,
             safe_qx(
@@ -65,9 +67,9 @@ sub source {
 
             my $specific = "debian/$bin.lintian-overrides.$arch";
 
-            tag 'multi-arch-same-package-has-arch-specific-overrides',
-              $specific
-              if $info->index_resolved_path($specific);
+            $self->tag('multi-arch-same-package-has-arch-specific-overrides',
+                $specific)
+              if $processable->index_resolved_path($specific);
         }
     }
 
@@ -78,22 +80,23 @@ sub binary {
     my ($self) = @_;
 
     my $pkg = $self->package;
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     if ($pkg =~ /^x?fonts-/) {
-        tag 'font-package-not-multi-arch-foreign'
-          unless $info->field('multi-arch', 'no') =~m/^(?:foreign|allowed)$/o;
+        $self->tag('font-package-not-multi-arch-foreign')
+          unless $processable->field('multi-arch', 'no')
+          =~m/^(?:foreign|allowed)$/o;
     }
 
-    my $multi = $info->unfolded_field('multi-arch');
+    my $multi = $processable->unfolded_field('multi-arch');
 
     return
       unless defined $multi;
 
-    my $architecture = $info->unfolded_field('architecture');
+    my $architecture = $processable->unfolded_field('architecture');
     if (defined $architecture) {
 
-        tag 'illegal-multi-arch-value', $architecture, $multi
+        $self->tag('illegal-multi-arch-value', $architecture, $multi)
           if $architecture eq 'all' && $multi eq 'same';
     }
 
@@ -104,14 +107,14 @@ sub always {
     my ($self) = @_;
 
     my $pkg = $self->package;
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    my $multi = $info->unfolded_field('multi-arch');
+    my $multi = $processable->unfolded_field('multi-arch');
 
     return
       unless defined $multi;
 
-    tag 'unknown-multi-arch-value', $pkg, $multi
+    $self->tag('unknown-multi-arch-value', $pkg, $multi)
       unless $multi =~ m/^(?:no|foreign|allowed|same)$/o;
 
     return;
