@@ -40,9 +40,9 @@ with 'Lintian::Check';
 sub always {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    my $uploaders = $info->unfolded_field('uploaders');
+    my $uploaders = $processable->unfolded_field('uploaders');
 
     return
       unless defined $uploaders;
@@ -62,18 +62,20 @@ sub always {
       split />\K\s*,\s*/, $uploaders;
 
     for my $member (@list) {
-        check_maintainer($member, 'uploader');
+        my @tags = check_maintainer($member, 'uploader');
+        $self->tag(@{$_}) for @tags;
+
         if (   ((true { $_ eq $member } @list) > 1)
             and($duplicate_uploaders{$member}++ == 0)) {
             $self->tag('duplicate-uploader', $member);
         }
     }
 
-    my $maintainer = $info->field('maintainer');
+    my $maintainer = $processable->field('maintainer');
     if (defined $maintainer) {
 
         $self->tag('maintainer-also-in-uploaders')
-          if $info->field('uploaders') =~ m/\Q$maintainer/;
+          if $processable->field('uploaders') =~ m/\Q$maintainer/;
     }
 
     return;
