@@ -27,7 +27,7 @@ use autodie;
 
 use List::MoreUtils qw(none);
 
-use Lintian::Spelling qw(check_spelling spelling_tag_emitter);
+use Lintian::Spelling qw(check_spelling);
 use Lintian::Util qw(internal_error strip);
 
 use constant PATCH_DESC_TEMPLATE => 'TODO: Put a short summary on'
@@ -38,10 +38,17 @@ use namespace::clean;
 
 with 'Lintian::Check';
 
+sub spelling_tag_emitter {
+    my ($self, @orig_args) = @_;
+    return sub {
+        return $self->tag(@orig_args, @_);
+    };
+}
+
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
     my $group = $self->group;
 
     # Some (cruft) checks are valid for every patch system, so we need
@@ -50,12 +57,12 @@ sub source {
 
     # Get build deps so we can decide which build system the
     # maintainer meant to use:
-    my $build_deps = $info->relation('build-depends-all');
+    my $build_deps = $processable->relation('build-depends-all');
     # Get source package format
-    my $format = $info->field('format', '');
+    my $format = $processable->field('format', '');
     my $quilt_format = ($format =~ /3\.\d+ \(quilt\)/) ? 1 : 0;
 
-    my $droot = $info->index_resolved_path('debian/');
+    my $droot = $processable->index_resolved_path('debian/');
     return if not $droot;
     my $dpdir = $droot->resolve_path('patches');
     my $patch_series;
@@ -218,7 +225,7 @@ sub source {
         }
         if ($quilt_format) { # 3.0 (quilt) specific checks
              # Format 3.0 packages may generate a debian-changes-$version patch
-            my $version = $info->field('version');
+            my $version = $processable->field('version');
             my $patch_header = $droot->resolve_path('source/patch-header');
             my $versioned_patch;
             $versioned_patch = $dpdir->resolve_path("debian-changes-$version")
@@ -274,7 +281,7 @@ sub source {
         $self->tag('more-than-one-patch-system');
     }
     my @direct;
-    open(my $fd, '<', $info->diffstat);
+    open(my $fd, '<', $processable->diffstat);
     while (<$fd>) {
         my ($file) = (m,^\s+(.*?)\s+\|,)
           or internal_error("syntax error in diffstat file: $_");
@@ -304,9 +311,9 @@ sub check_patch {
 
     if (none { /(spelling|typo)/i } ($patch_file, $description)) {
         my $tag_emitter
-          = spelling_tag_emitter('spelling-error-in-patch-description',
+          = $self->spelling_tag_emitter('spelling-error-in-patch-description',
             $patch_file);
-        check_spelling($description, $group->info->spelling_exceptions,
+        check_spelling($description, $group->spelling_exceptions,
             $tag_emitter, 0);
     }
     # Use --strip=1 to strip off the first layer of directory in case
